Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(692)

Unified Diff: webrtc/voice_engine/file_player.h

Issue 2791453004: Revert of Supporting 48kHz PCM file. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/modules/media_file/media_file_utility.cc ('k') | webrtc/voice_engine/file_player.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/voice_engine/file_player.h
diff --git a/webrtc/voice_engine/file_player.h b/webrtc/voice_engine/file_player.h
index 1a321f64073de07e7acc9692d04ae6c12c70ff67..956016f07f4555d448c8e1c5188e64c26eae8d59 100644
--- a/webrtc/voice_engine/file_player.h
+++ b/webrtc/voice_engine/file_player.h
@@ -23,8 +23,8 @@
class FilePlayer {
public:
- // The largest decoded frame size in samples (120ms with 48kHz sample rate).
- enum { MAX_AUDIO_BUFFER_IN_SAMPLES = 120 * 48 };
+ // The largest decoded frame size in samples (60ms with 32kHz sample rate).
+ enum { MAX_AUDIO_BUFFER_IN_SAMPLES = 60 * 32 };
enum { MAX_AUDIO_BUFFER_IN_BYTES = MAX_AUDIO_BUFFER_IN_SAMPLES * 2 };
// Note: will return NULL for unsupported formats.
« no previous file with comments | « webrtc/modules/media_file/media_file_utility.cc ('k') | webrtc/voice_engine/file_player.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698